Class DeviceValuesGraphicsAdd
    Public Sub Main(ByVal Parms As Object)
        ''
        '' Add Custom Graphics to a Device
        ''   They will be displayed on the HS Status Page
        ''
        Dim Pairs As String
        Dim theDevice As String = "a1"

        '' Add Value/String Pairs to Device
        ''   You must add value/string pairs for image/value pairs to work
        Pairs = "One" & Chr(2) & "1"                    ' String for value of 1
        Pairs = Pairs & Chr(1)                          ' Separator between value/string pairs
        Pairs = Pairs & "Two" & Chr(2) & "2"            ' String for value of 2
        hs.DeviceValuesAdd(theDevice, Pairs, True)

        '' Add Image/Value Pairs to Device
        ''   The images reside in:  \Homeseer 2\html\images
        Pairs = "one.gif" & Chr(2) & "1"                ' Image for value of 1
        Pairs = Pairs & Chr(1)                          ' Separator between image/value pairs
        Pairs = Pairs & "two.gif" & Chr(2) & "2"        ' Image for value of 2
        hs.DeviceValuesGraphicsAdd(theDevice, Pairs)    ' Add the image/value pairs to the device
    End Sub
End Class
Class ToggleDeviceSample
    Public Sub Main(ByVal Parms As String)
        ''
        '' Toggle the Specified Device ON/OFF
        ''   DIM is considered ON
        ''
        Dim devStatus As Integer
        Dim theDevice As String

        '' Get Device from the Parms
        theDevice = Parms.ToString
        '' Get the Device Status
        devStatus = hs.DeviceStatus(theDevice)
        '' Toggle it
        Select Case devStatus
            Case 2, 4, 5
                '' Device ON or DIM, turn it OFF
                hs.ExecX10(Parms, "Off")
            Case 3
                '' Device OFF, turn it ON
                hs.ExecX10(Parms, "On")
        End Select
    End Sub
End Class
Class NonHsParmsSample
    Public Sub Main(ByVal parms() As Object)
        If parms.Length > 0 Then
            For i As Integer = 0 To parms.Length - 1
                hs.WriteLog("NonHsParmsSample", "Parameter" & i.ToString & "=" & parms(i).ToString)
            Next
        Else
            hs.WriteLog("NonHsParmsSample", "No Parameters Found")
        End If

    End Sub
End Class
Class MultipleEntryPoints
    ''
    '' This script illustrates how to have multiple 'scripts' share common functions
    ''
    '' A Function, 'ScheduleDeviceAction' is defined to issue a delayed command
    '' 
    '' Two HS callable Entry Points are defined, 'FrontDoorMotion' and 'BackDoorMotion'
    ''
    '' Each Entry Point uses 'ScheduleDeviceAction'
    ''
    '' An optional Parameter is used by both 'FrontDoorMotion' and 'BackDoorMotion'
    ''   to specify an OFF delay (defaults to one minute)
    ''
    '' To call 'FrontDoorMotion' from an HS Event:
    ''     Create an Event with an Action=Run Script
    ''     For 'Script Name' enter: MultipleEntryPoints
    ''     For 'Optional Parameters' enter: ("FrontDoorMotion","30")
    '' This will turn the light on, and then turn it off 30 minutes later
    ''
    Public Sub FrontDoorMotion(ByVal Parms As Object)
        ''
        '' Motion at Front Door, Turn the light on, and
        ''   then OFF later (parameter=delay in seconds)
        ''
        Dim Delay As Integer

        '' Get the seconds to delay from the parameters
        If Parms.ToString.Length < 1 Then
            '' Parm not entered, default to one minute
            Delay = 60
        Else
            '' Get the specified Delay
            Delay = CInt(Parms.ToString)
        End If

        '' Turn the light ON
        hs.ExecX10ByName("OutSide Front Porch", "ON")
        '' Schedule it OFF
        ScheduleDeviceAction("Outside Front Porch", "OFF", Delay)
    End Sub
    Public Sub BackDoorMotion(ByVal Parms As Object)
        ''
        '' Motion at Back Door, Turn the light on, and
        ''   then OFF later (parameter=delay in seconds)
        ''
        Dim Delay As Integer

        '' Get the seconds to delay from the parameters
        If Parms.ToString.Length < 1 Then
            '' Parm not entered, default to one minute
            Delay = 60
        Else
            '' Get the specified Delay
            Delay = CInt(Parms.ToString)
        End If

        '' Turn the light ON
        hs.ExecX10ByName("OutSide Back Porch", "ON")
        '' Schedule it OFF
        ScheduleDeviceAction("Outside Back Porch", "OFF", Delay)
    End Sub
    Private Sub ScheduleDeviceAction(ByVal theDevice As String, ByVal theAction As String, ByVal theDelay As Integer)
        ''
        '' Schedule 'theAction' for 'theDevice' in 'theDelay' seconds
        ''
        Dim TempEventName As String
        Dim anEventRef As Integer
        Dim anEvent As Scheduler.Classes.EventClass
        Dim retValue As String

        TempEventName = "Delayed_" & theDevice & "_" & theAction.ToString
        If theDelay <= 0 Then
            '' No Delay requested, so do it NOW
            hs.ExecX10ByName(theDevice, theAction)
        Else
            '' Delay requested, schedule it
            '''' Remove any Existing Events
            hs.RemoveDelayedEvent("", TempEventName)        ' remove any scheduled event executions
            hs.DeleteEvent(TempEventName)                   ' remove the event definition
            '''' Create Manual Event to be triggered after all have left house
            anEventRef = hs.NewEventGetRef(TempEventName)                               'create new event
            anEvent = hs.GetEventByRef(anEventRef)                                      'get reference to it
            anEvent.misc = &H10                                                         'delete after trigger
            anEvent.ev_abs_time = Scheduler.Classes.trigger_type_values.TYPE_MANUAL     'manual event
            '''' Add the Device Action to the Event
            retValue = hs.AddAction(anEventRef, _
                Scheduler.Classes.action_type_value.ACTION_DEVICE, _
                hs.GetDeviceRefByName(theDevice), _
                theAction)
            '''' Now that the manual event has been created, schedule it 
            ''''   It will delete itself after it runs
            hs.DelayTrigger(theDelay, TempEventName)
        End If
    End Sub
End Class
Class SaveDeviceStatusIntoDeviceString
    ''
    '' Specify the DeviceCode  (A1)  in the parameters
    ''   the DeviceString will be set to the Current DeviceStatus
    ''
    Public Sub Main(ByVal Parms As Object)
        Dim dev As String

        dev = Parms.ToString               'get device code from script argument
        Select Case hs.DeviceStatus(dev)
            Case 2
                hs.SetDeviceString(dev, "ON")
            Case 3
                hs.SetDeviceString(dev, "OFF")
            Case 4, 5
                hs.SetDeviceString(dev, "DIM")
            Case Else
                hs.SetDeviceString(dev, "????")
        End Select
    End Sub
End Class
Class EnumerateDevices
    Public Sub Main(ByVal Parms As String)
        GetAllDevices()
    End Sub
    Private Sub GetAllDevices()
        Dim anHsDevice As Scheduler.Classes.DeviceClass
        Dim hsDevices As Scheduler.clsDeviceEnumeration

        Do
            hsDevices = CType(hs.GetDeviceEnumerator, Scheduler.clsDeviceEnumeration)
            Do While Not hsDevices.Finished
                If hsDevices.CountChanged Then
                    hs.WriteLog("EnumerateDevices", "HS Devices Changed, Restarting Enumeration")
                    Exit Do
                End If
                '' Write Device Location and Name to HS Log
                anHsDevice = hsDevices.GetNext
                hs.WriteLog("EnumerateDevices", "Found Device:  " & anHsDevice.location & "-" & anHsDevice.Name)
            Loop
        Loop While hsDevices.CountChanged
    End Sub
End Class